@@ -38,7 +38,7 @@ class MetaDataImport(object):
         self.db_sql = None
         self.adm_sql = None
         self.db_module = task.task_db_module
-        self.items_hidden_fields = []
+        self.items_hidden_fields = ['f_gen_name']
         self.params_hidden_fields = [
                 'f_safe_mode', 'f_debugging', 'f_modification',
                 'f_client_modified', 'f_server_modified',
@@ -64,10 +64,6 @@ class MetaDataImport(object):
             self.error = 'Metadata can not be imported into an existing SQLITE project'
             self.show_error(self.error)
 
-    def update_gen_names(self):
-        if not get_db_module(self.db_type).NEED_GENERATOR:
-            self.items_hidden_fields.append('f_gen_name')
-
     def update_indexes(self):
         if self.new_db_type == FIREBIRD or self.db_type == FIREBIRD:
             item = self.new_items['sys_indices']
@@ -132,7 +128,6 @@ class MetaDataImport(object):
                     os.remove(file_name)
                     self.new_db_type = data_lists.get('db_type')
                     if self.new_db_type != self.db_type:
-                        self.update_gen_names()
                         self.update_idents()
             except Exception as e:
                 self.task.log.exception(e)
@@ -378,10 +373,13 @@ class MetaDataImport(object):
 
     def check_generator(self, item, delta):
         for d in delta:
-            if d.rec_inserted() and item.task.task_db_module.NEED_GENERATOR and \
-                d.f_primary_key.value and not d.f_gen_name.value:
+            module = get_db_module(self.db_type)
+            if d.rec_inserted() and module.NEED_GENERATOR and \
+                d.f_primary_key.value and not d.f_gen_name.value and \
+                not d.f_virtual_table.value:
+                case = module.identifier_case
                 d.edit()
-                d.f_gen_name.value = '%s_SEQ' % d.f_table_name.value
+                d.f_gen_name.value = case('%s_SEQ' % d.f_table_name.value)
                 d.post()
 
     def refresh_old_item(self, item_name):
