@@ -753,7 +753,7 @@ class App(object):
                                 if not ext in consts.upload_file_ext:
                                     r['error'] = '%s - %s' % (request.form.get('file_name'), consts.lang['upload_not_allowed'])
                                     self.log.error(r['error'])
-                            file_name = ('%s_%s%s') % (base, datetime.datetime.now().strftime('%Y-%m-%d_%H:%M:%S.%f'), ext)
+                            file_name = ('%s_%s%s') % (base, datetime.datetime.now().strftime('%Y-%m-%d_%H-%M-%S_%f'), ext)
                             file_name = secure_filename(file_name)
                             file_name = file_name.replace('?', '')
                             if task_id == 0:
